@@ -25,7 +25,6 @@ import botocore
 from botocore import exceptions as boto_exceptions
 from botocore import stub
 from oslo_config import cfg
-from oslo_utils.secretutils import md5
 from oslo_utils import units
 
 import glance_store as store
@@ -90,6 +89,8 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
                     s3_store_access_key='user',
                     s3_store_secret_key='key',
                     s3_store_host='https://s3-region1.com',
+                    s3_store_region_name='custom_region_name',
+                    s3_store_cacert='path/to/cert/bundle.pem',
                     s3_store_bucket='glance',
                     s3_store_large_object_size=S3_CONF[
                         's3_store_large_object_size'
@@ -132,6 +133,40 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
             self.assertRaises(boto_exceptions.InvalidDNSNameError,
                               self.store.get, loc)
 
+    @mock.patch('glance_store.location.Location')
+    @mock.patch.object(boto3.session.Session, "client")
+    def test_client_custom_region_name(self, mock_client, mock_loc):
+        """Test a custom s3_store_region_name in config"""
+        mock_loc.accesskey = 'abcd'
+        mock_loc.secretkey = 'efgh'
+        mock_loc.bucket = 'bucket1'
+        self.store._create_s3_client(mock_loc)
+        mock_client.assert_called_with(
+            config=mock.ANY,
+            endpoint_url='https://s3-region1.com',
+            region_name='custom_region_name',
+            service_name='s3',
+            use_ssl=False,
+            verify='path/to/cert/bundle.pem',
+        )
+
+    @mock.patch('glance_store.location.Location')
+    @mock.patch.object(boto3.session.Session, "client")
+    def test_client_custom_ca_cert_bundle(self, mock_client, mock_loc):
+        """Test a custom s3_store_cacert in config"""
+        mock_loc.accesskey = 'abcd'
+        mock_loc.secretkey = 'efgh'
+        mock_loc.bucket = 'bucket1'
+        self.store._create_s3_client(mock_loc)
+        mock_client.assert_called_with(
+            config=mock.ANY,
+            endpoint_url='https://s3-region1.com',
+            region_name='custom_region_name',
+            service_name='s3',
+            use_ssl=False,
+            verify='path/to/cert/bundle.pem',
+        )
+
     @mock.patch.object(boto3.session.Session, "client")
     def test_get(self, mock_client):
         """Test a "normal" retrieval of an image in chunks."""
@@ -211,8 +246,8 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
         # 5KiB is smaller than WRITE_CHUNKSIZE
         expected_s3_size = FIVE_KB
         expected_s3_contents = b"*" * expected_s3_size
-        expected_checksum = md5(expected_s3_contents,
-                                usedforsecurity=False).hexdigest()
+        expected_checksum = hashlib.md5(expected_s3_contents,
+                                        usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(expected_s3_contents).hexdigest()
         expected_location = format_s3_location(
             S3_CONF['s3_store_access_key'],
@@ -264,8 +299,8 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
         # but smaller than s3_store_large_object_size
         expected_s3_size = 8 * units.Mi
         expected_s3_contents = b"*" * expected_s3_size
-        expected_checksum = md5(expected_s3_contents,
-                                usedforsecurity=False).hexdigest()
+        expected_checksum = hashlib.md5(expected_s3_contents,
+                                        usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(expected_s3_contents).hexdigest()
         expected_location = format_s3_location(
             S3_CONF['s3_store_access_key'],
@@ -318,8 +353,8 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
         expected_image_id = str(uuid.uuid4())
         expected_s3_size = FIVE_KB
         expected_s3_contents = b"*" * expected_s3_size
-        expected_checksum = md5(expected_s3_contents,
-                                usedforsecurity=False).hexdigest()
+        expected_checksum = hashlib.md5(expected_s3_contents,
+                                        usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(expected_s3_contents).hexdigest()
         expected_location = format_s3_location(
             S3_CONF['s3_store_access_key'],
@@ -392,8 +427,8 @@ class TestMultiS3Store(base.MultiStoreBaseTest,
         expected_image_id = str(uuid.uuid4())
         expected_s3_size = 16 * units.Mi
         expected_s3_contents = b"*" * expected_s3_size
-        expected_checksum = md5(expected_s3_contents,
-                                usedforsecurity=False).hexdigest()
+        expected_checksum = hashlib.md5(expected_s3_contents,
+                                        usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(expected_s3_contents).hexdigest()
         expected_location = format_s3_location(
             S3_CONF['s3_store_access_key'],
