@@ -16,6 +16,7 @@
 """Tests the Multiple VMware Datastore backend store"""
 
 import hashlib
+import io
 from unittest import mock
 import uuid
 
@@ -25,7 +26,6 @@ from oslo_vmware import api
 from oslo_vmware import exceptions as vmware_exceptions
 from oslo_vmware.objects import datacenter as oslo_datacenter
 from oslo_vmware.objects import datastore as oslo_datastore
-import six
 
 import glance_store as store
 import glance_store._drivers.vmware_datastore as vm_store
@@ -129,7 +129,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         self.store.configure()
 
     def _mock_http_connection(self):
-        return mock.patch('six.moves.http_client.HTTPConnection')
+        return mock.patch('http.client.HTTPConnection')
 
     def test_location_url_prefix_is_set(self):
         expected_url_prefix = "vsphere://127.0.0.1/openstack_glance"
@@ -175,12 +175,12 @@ class TestMultiStore(base.MultiStoreBaseTest,
         expected_image_id = str(uuid.uuid4())
         expected_size = FIVE_KB
         expected_contents = b"*" * expected_size
-        hash_code = hashlib.md5(expected_contents)
+        hash_code = hashlib.md5(expected_contents, usedforsecurity=False)
         expected_checksum = hash_code.hexdigest()
         fake_size.__get__ = mock.Mock(return_value=expected_size)
         expected_cookie = 'vmware_soap_session=fake-uuid'
         fake_cookie.return_value = expected_cookie
-        expected_headers = {'Content-Length': six.text_type(expected_size),
+        expected_headers = {'Content-Length': str(expected_size),
                             'Cookie': expected_cookie}
         with mock.patch('hashlib.md5') as md5:
             md5.return_value = hash_code
@@ -189,7 +189,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
                 VMWARE_DS['vmware_store_image_dir'],
                 expected_image_id,
                 VMWARE_DS['vmware_datastores'])
-            image = six.BytesIO(expected_contents)
+            image = io.BytesIO(expected_contents)
             with mock.patch('requests.Session.request') as HttpConn:
                 HttpConn.return_value = utils.fake_response()
                 location, size, checksum, metadata = self.store.add(
@@ -216,7 +216,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         expected_image_id = str(uuid.uuid4())
         expected_size = FIVE_KB
         expected_contents = b"*" * expected_size
-        hash_code = hashlib.md5(expected_contents)
+        hash_code = hashlib.md5(expected_contents, usedforsecurity=False)
         expected_checksum = hash_code.hexdigest()
         fake_size.__get__ = mock.Mock(return_value=expected_size)
         with mock.patch('hashlib.md5') as md5:
@@ -226,7 +226,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
                 VMWARE_DS['vmware_store_image_dir'],
                 expected_image_id,
                 VMWARE_DS['vmware_datastores'])
-            image = six.BytesIO(expected_contents)
+            image = io.BytesIO(expected_contents)
             with mock.patch('requests.Session.request') as HttpConn:
                 HttpConn.return_value = utils.fake_response()
                 location, size, checksum, metadata = self.store.add(
@@ -246,7 +246,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         image_id = str(uuid.uuid4())
         size = FIVE_KB
         contents = b"*" * size
-        image = six.BytesIO(contents)
+        image = io.BytesIO(contents)
         with mock.patch('requests.Session.request') as HttpConn:
             HttpConn.return_value = utils.fake_response()
             location, size, checksum, multihash, metadata = self.store.add(
@@ -263,7 +263,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         image_id = str(uuid.uuid4())
         size = FIVE_KB
         contents = b"*" * size
-        image = six.BytesIO(contents)
+        image = io.BytesIO(contents)
         with mock.patch('requests.Session.request') as HttpConn:
             HttpConn.return_value = utils.fake_response()
             location, size, checksum, multihash, metadata = self.store.add(
@@ -329,8 +329,9 @@ class TestMultiStore(base.MultiStoreBaseTest,
 
     def test_reader_full(self):
         content = b'XXX'
-        image = six.BytesIO(content)
-        expected_checksum = hashlib.md5(content).hexdigest()
+        image = io.BytesIO(content)
+        expected_checksum = hashlib.md5(
+            content, usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(content).hexdigest()
         reader = vm_store._Reader(image, self.hash_algo)
         ret = reader.read()
@@ -341,8 +342,9 @@ class TestMultiStore(base.MultiStoreBaseTest,
 
     def test_reader_partial(self):
         content = b'XXX'
-        image = six.BytesIO(content)
-        expected_checksum = hashlib.md5(b'X').hexdigest()
+        image = io.BytesIO(content)
+        expected_checksum = hashlib.md5(
+            b'X', usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(b'X').hexdigest()
         reader = vm_store._Reader(image, self.hash_algo)
         ret = reader.read(1)
@@ -353,7 +355,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
 
     def test_reader_with_verifier(self):
         content = b'XXX'
-        image = six.BytesIO(content)
+        image = io.BytesIO(content)
         verifier = mock.MagicMock(name='mock_verifier')
         reader = vm_store._Reader(image, self.hash_algo, verifier)
         reader.read()
@@ -410,7 +412,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         expected_image_id = str(uuid.uuid4())
         expected_size = FIVE_KB
         expected_contents = b"*" * expected_size
-        image = six.BytesIO(expected_contents)
+        image = io.BytesIO(expected_contents)
         self.session = mock.Mock()
         with mock.patch('requests.Session.request') as HttpConn:
             HttpConn.return_value = utils.fake_response(status_code=401)
@@ -425,7 +427,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         expected_image_id = str(uuid.uuid4())
         expected_size = FIVE_KB
         expected_contents = b"*" * expected_size
-        image = six.BytesIO(expected_contents)
+        image = io.BytesIO(expected_contents)
         self.session = mock.Mock()
         with self._mock_http_connection() as HttpConn:
             HttpConn.return_value = utils.fake_response(status_code=500,
@@ -467,7 +469,7 @@ class TestMultiStore(base.MultiStoreBaseTest,
         expected_image_id = str(uuid.uuid4())
         expected_size = FIVE_KB
         expected_contents = b"*" * expected_size
-        image = six.BytesIO(expected_contents)
+        image = io.BytesIO(expected_contents)
         self.session = mock.Mock()
         with mock.patch('requests.Session.request') as HttpConn:
             HttpConn.request.side_effect = IOError
