@@ -24,7 +24,6 @@ import boto3
 import botocore
 from botocore import exceptions as boto_exceptions
 from botocore import stub
-from oslo_utils.secretutils import md5
 from oslo_utils import units
 
 from glance_store._drivers import s3
@@ -41,6 +40,7 @@ FIVE_KB = 5 * units.Ki
 S3_CONF = {
     's3_store_access_key': 'user',
     's3_store_secret_key': 'key',
+    's3_store_region_name': '',
     's3_store_host': 'localhost',
     's3_store_bucket': 'glance',
     's3_store_large_object_size': 9,        # over 9MB is large
@@ -84,6 +84,54 @@ class TestStore(base.StoreBaseTest,
             self.assertRaises(boto_exceptions.InvalidDNSNameError,
                               self.store.get, loc)
 
+    @mock.patch('glance_store.location.Location')
+    @mock.patch.object(boto3.session.Session, "client")
+    def test_client_custom_region_name(self, mock_client, mock_loc):
+        """Test a custom s3_store_region_name in config"""
+        self.config(s3_store_host='http://example.com')
+        self.config(s3_store_region_name='regionOne')
+        self.config(s3_store_bucket_url_format='path')
+        self.store.configure()
+
+        mock_loc.accesskey = 'abcd'
+        mock_loc.secretkey = 'efgh'
+        mock_loc.bucket = 'bucket1'
+
+        self.store._create_s3_client(mock_loc)
+
+        mock_client.assert_called_with(
+            config=mock.ANY,
+            endpoint_url='http://example.com',
+            region_name='regionOne',
+            service_name='s3',
+            use_ssl=False,
+            verify=None,
+        )
+
+    @mock.patch('glance_store.location.Location')
+    @mock.patch.object(boto3.session.Session, "client")
+    def test_client_custom_ca_cert_bundle(self, mock_client, mock_loc):
+        """Test a custom s3_store_cacert in config"""
+        self.config(s3_store_host='http://example.com')
+        self.config(s3_store_cacert='path/to/cert/bundle.pem')
+        self.config(s3_store_bucket_url_format='path')
+        self.store.configure()
+
+        mock_loc.accesskey = 'abcd'
+        mock_loc.secretkey = 'efgh'
+        mock_loc.bucket = 'bucket1'
+
+        self.store._create_s3_client(mock_loc)
+
+        mock_client.assert_called_with(
+            config=mock.ANY,
+            endpoint_url='http://example.com',
+            region_name=None,
+            service_name='s3',
+            use_ssl=False,
+            verify='path/to/cert/bundle.pem',
+        )
+
     @mock.patch.object(boto3.session.Session, "client")
     def test_get(self, mock_client):
         """Test a "normal" retrieval of an image in chunks."""
@@ -160,8 +208,8 @@ class TestStore(base.StoreBaseTest,
         # 5KiB is smaller than WRITE_CHUNKSIZE
         expected_s3_size = FIVE_KB
         expected_s3_contents = b"*" * expected_s3_size
-        expected_checksum = md5(expected_s3_contents,
-                                usedforsecurity=False).hexdigest()
+        expected_checksum = hashlib.md5(expected_s3_contents,
+                                        usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(expected_s3_contents).hexdigest()
         expected_location = format_s3_location(
             S3_CONF['s3_store_access_key'],
@@ -212,8 +260,8 @@ class TestStore(base.StoreBaseTest,
         # but smaller than s3_store_large_object_size
         expected_s3_size = 8 * units.Mi
         expected_s3_contents = b"*" * expected_s3_size
-        expected_checksum = md5(expected_s3_contents,
-                                usedforsecurity=False).hexdigest()
+        expected_checksum = hashlib.md5(expected_s3_contents,
+                                        usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(expected_s3_contents).hexdigest()
         expected_location = format_s3_location(
             S3_CONF['s3_store_access_key'],
@@ -285,8 +333,8 @@ class TestStore(base.StoreBaseTest,
         expected_image_id = str(uuid.uuid4())
         expected_s3_size = 16 * units.Mi
         expected_s3_contents = b"*" * expected_s3_size
-        expected_checksum = md5(expected_s3_contents,
-                                usedforsecurity=False).hexdigest()
+        expected_checksum = hashlib.md5(expected_s3_contents,
+                                        usedforsecurity=False).hexdigest()
         expected_multihash = hashlib.sha256(expected_s3_contents).hexdigest()
         expected_location = format_s3_location(
             S3_CONF['s3_store_access_key'],
